pub struct MemoryManager<T: Token> { /* private fields */ }Expand description
Utility struct for managing memory allocation and string interning. In particular, it
provides a CSHandler implementation for interning control
sequence names (if applicable).
Implementations
Sourceimpl<T: Token> MemoryManager<T>
impl<T: Token> MemoryManager<T>
Sourcepub fn get_bytes(&mut self) -> Vec<u8> ⓘ
pub fn get_bytes(&mut self) -> Vec<u8> ⓘ
Provides an empty Vec<u8> that can be returned using return_bytes, avoiding
the need to allocate a new Vec<u8> every time.
Sourcepub fn return_bytes(&mut self, b: Vec<u8>)
pub fn return_bytes(&mut self, b: Vec<u8>)
Returns a Vec<u8> to the memory manager, which clears it and keeps it in memory for reuse.
Sourcepub fn get_string(&mut self) -> String
pub fn get_string(&mut self) -> String
Provides an empty String that can be returned using return_string, avoiding
the need to allocate a new String every time.
Sourcepub fn return_string(&mut self, s: String)
pub fn return_string(&mut self, s: String)
Returns a String to the memory manager, which clears it and keeps it in memory for reuse.
Sourcepub fn get_token_vec(&mut self) -> Vec<T>
pub fn get_token_vec(&mut self) -> Vec<T>
Provides an empty Vec<T> that can be returned using return_token_vec, avoiding
the need to allocate a new Vec<T> every time.
Sourcepub fn return_token_vec(&mut self, v: Vec<T>)
pub fn return_token_vec(&mut self, v: Vec<T>)
Returns a Vec<T> to the memory manager, which clears it and keeps it in memory for reuse.
Sourcepub fn new_with_cs_interner(
cs_interner: <T::CS as CSName<T::Char>>::Handler,
) -> Self
pub fn new_with_cs_interner( cs_interner: <T::CS as CSName<T::Char>>::Handler, ) -> Self
Returns a new memory manager with the given control sequence interner.
Sourcepub fn set_cs_interner(
&mut self,
cs_interner: <T::CS as CSName<T::Char>>::Handler,
)
pub fn set_cs_interner( &mut self, cs_interner: <T::CS as CSName<T::Char>>::Handler, )
Sets the control sequence interner.
Sourcepub fn cs_interner_mut(&mut self) -> &mut <T::CS as CSName<T::Char>>::Handler
pub fn cs_interner_mut(&mut self) -> &mut <T::CS as CSName<T::Char>>::Handler
Returns the control sequence interner mutably.
Sourcepub fn cs_interner(&self) -> &<T::CS as CSName<T::Char>>::Handler
pub fn cs_interner(&self) -> &<T::CS as CSName<T::Char>>::Handler
Returns the control sequence interner.
Sourcepub fn empty_list(&self) -> TokenList<T>
pub fn empty_list(&self) -> TokenList<T>
Returns an empty token list.